# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.ports_api import PortsApi


class TestPortsApi(unittest.TestCase):
    """PortsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PortsApi()

    def tearDown(self) -> None:
        pass

    def test_assign_native_vlan(self) -> None:
        """Test case for assign_native_vlan

        Assign a native VLAN
        """
        pass

    def test_assign_port(self) -> None:
        """Test case for assign_port

        Assign a port to virtual network
        """
        pass

    def test_bond_port(self) -> None:
        """Test case for bond_port

        Enabling bonding
        """
        pass

    def test_convert_layer2(self) -> None:
        """Test case for convert_layer2

        Convert to Layer 2
        """
        pass

    def test_convert_layer3(self) -> None:
        """Test case for convert_layer3

        Convert to Layer 3
        """
        pass

    def test_create_port_vlan_assignment_batch(self) -> None:
        """Test case for create_port_vlan_assignment_batch

        Create a new Port-VLAN Assignment management batch
        """
        pass

    def test_delete_native_vlan(self) -> None:
        """Test case for delete_native_vlan

        Remove native VLAN
        """
        pass

    def test_disbond_port(self) -> None:
        """Test case for disbond_port

        Disabling bonding
        """
        pass

    def test_find_port_by_id(self) -> None:
        """Test case for find_port_by_id

        Retrieve a port
        """
        pass

    def test_find_port_vlan_assignment_batch_by_port_id_and_batch_id(self) -> None:
        """Test case for find_port_vlan_assignment_batch_by_port_id_and_batch_id

        Retrieve a VLAN Assignment Batch's details
        """
        pass

    def test_find_port_vlan_assignment_batches(self) -> None:
        """Test case for find_port_vlan_assignment_batches

        List the VLAN Assignment Batches for a port
        """
        pass

    def test_find_port_vlan_assignment_by_port_id_and_assignment_id(self) -> None:
        """Test case for find_port_vlan_assignment_by_port_id_and_assignment_id

        Show a particular Port VLAN assignment's details
        """
        pass

    def test_find_port_vlan_assignments(self) -> None:
        """Test case for find_port_vlan_assignments

        List Current VLAN assignments for a port
        """
        pass

    def test_unassign_port(self) -> None:
        """Test case for unassign_port

        Unassign a port
        """
        pass


if __name__ == '__main__':
    unittest.main()
