# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.vlans_api import VLANsApi


class TestVLANsApi(unittest.TestCase):
    """VLANsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = VLANsApi()

    def tearDown(self) -> None:
        pass

    def test_create_virtual_network(self) -> None:
        """Test case for create_virtual_network

        Create a virtual network
        """
        pass

    def test_delete_virtual_network(self) -> None:
        """Test case for delete_virtual_network

        Delete a virtual network
        """
        pass

    def test_find_virtual_networks(self) -> None:
        """Test case for find_virtual_networks

        Retrieve all virtual networks
        """
        pass

    def test_get_virtual_network(self) -> None:
        """Test case for get_virtual_network

        Get a virtual network
        """
        pass

    def test_update_virtual_network(self) -> None:
        """Test case for update_virtual_network

        Updates the virtual network
        """
        pass


if __name__ == '__main__':
    unittest.main()
