# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.interconnection_pricing_list import InterconnectionPricingList

class TestInterconnectionPricingList(unittest.TestCase):
    """InterconnectionPricingList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InterconnectionPricingList:
        """Test InterconnectionPricingList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InterconnectionPricingList`
        """
        model = InterconnectionPricingList()
        if include_optional:
            return InterconnectionPricingList(
                href = '',
                provider_pricing = [
                    equinix.services.metalv1.models.interconnection_pricing_list_provider_pricing_inner.InterconnectionPricingList_provider_pricing_inner(
                        href = '', 
                        provider = 'CSP_AWS', 
                        tiers = [
                            equinix.services.metalv1.models.interconnection_pricing_list_provider_pricing_inner_tiers_inner.InterconnectionPricingList_provider_pricing_inner_tiers_inner(
                                bandwidth = 500, 
                                billing_cycle = 'monthly', 
                                href = '', 
                                price = 10.04, )
                            ], )
                    ]
            )
        else:
            return InterconnectionPricingList(
        )
        """

    def testInterconnectionPricingList(self):
        """Test InterconnectionPricingList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
