# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.user_verification_tokens_api import UserVerificationTokensApi


class TestUserVerificationTokensApi(unittest.TestCase):
    """UserVerificationTokensApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserVerificationTokensApi()

    def tearDown(self) -> None:
        pass

    def test_consume_verification_request(self) -> None:
        """Test case for consume_verification_request

        Verify a user using an email verification token
        """
        pass

    def test_create_validation_request(self) -> None:
        """Test case for create_validation_request

        Create an email verification request
        """
        pass


if __name__ == '__main__':
    unittest.main()
