# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.support_request_api import SupportRequestApi


class TestSupportRequestApi(unittest.TestCase):
    """SupportRequestApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SupportRequestApi()

    def tearDown(self) -> None:
        pass

    def test_request_support(self) -> None:
        """Test case for request_support

        Create a support ticket
        """
        pass


if __name__ == '__main__':
    unittest.main()
