# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.organization_list import OrganizationList

class TestOrganizationList(unittest.TestCase):
    """OrganizationList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationList:
        """Test OrganizationList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationList`
        """
        model = OrganizationList()
        if include_optional:
            return OrganizationList(
                href = '',
                meta = equinix.services.metalv1.models.meta.Meta(
                    current_page = 56, 
                    first = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    href = '', 
                    last = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    last_page = 56, 
                    next = , 
                    previous = , 
                    self = , 
                    total = 56, ),
                organizations = [
                    equinix.services.metalv1.models.organization.Organization(
                        address = equinix.services.metalv1.models.address.Address(
                            address2 = '', 
                            city = '', 
                            coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                                href = '', 
                                latitude = '', 
                                longitude = '', ), 
                            country = '', 
                            href = '', 
                            state = '', 
                            zip_code = '', ), 
                        billing_address = equinix.services.metalv1.models.address.Address(
                            address2 = '', 
                            city = '', 
                            country = '', 
                            href = '', 
                            state = '', 
                            zip_code = '', ), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        credit_amount = 1.337, 
                        customdata = equinix.services.metalv1.models.customdata.customdata(), 
                        description = '', 
                        enforce_2fa_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        href = '', 
                        id = '', 
                        logo = '', 
                        members = [
                            equinix.services.metalv1.models.href.Href(
                                href = '', )
                            ], 
                        memberships = [
                            equinix.services.metalv1.models.href.Href(
                                href = '', )
                            ], 
                        name = '', 
                        projects = [
                            
                            ], 
                        terms = 56, 
                        twitter = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        website = '', )
                    ]
            )
        else:
            return OrganizationList(
        )
        """

    def testOrganizationList(self):
        """Test OrganizationList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
