# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.projects_api import ProjectsApi


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProjectsApi()

    def tearDown(self) -> None:
        pass

    def test_create_project(self) -> None:
        """Test case for create_project

        Create a project
        """
        pass

    def test_create_project_invitation(self) -> None:
        """Test case for create_project_invitation

        Create an invitation for a project
        """
        pass

    def test_create_transfer_request(self) -> None:
        """Test case for create_transfer_request

        Create a transfer request
        """
        pass

    def test_delete_project(self) -> None:
        """Test case for delete_project

        Delete the project
        """
        pass

    def test_find_ip_reservation_customdata(self) -> None:
        """Test case for find_ip_reservation_customdata

        Retrieve the custom metadata of an IP Reservation
        """
        pass

    def test_find_project_by_id(self) -> None:
        """Test case for find_project_by_id

        Retrieve a project
        """
        pass

    def test_find_project_customdata(self) -> None:
        """Test case for find_project_customdata

        Retrieve the custom metadata of a project
        """
        pass

    def test_find_project_invitations(self) -> None:
        """Test case for find_project_invitations

        Retrieve project invitations
        """
        pass

    def test_find_project_memberships(self) -> None:
        """Test case for find_project_memberships

        Retrieve project memberships
        """
        pass

    def test_find_projects(self) -> None:
        """Test case for find_projects

        Retrieve all projects
        """
        pass

    def test_find_projects_all_pages(self):
        """Test case for find_projects_all_pages

        Retrieve all projects  # noqa: E501
        """
        pass

    def test_update_project(self) -> None:
        """Test case for update_project

        Update the project
        """
        pass


if __name__ == '__main__':
    unittest.main()
