# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_prices_report import SpotPricesReport

class TestSpotPricesReport(unittest.TestCase):
    """SpotPricesReport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotPricesReport:
        """Test SpotPricesReport
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotPricesReport`
        """
        model = SpotPricesReport()
        if include_optional:
            return SpotPricesReport(
                ams1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                atl1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                dfw1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                ewr1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                fra1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                href = '',
                iad1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                lax1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                nrt1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                ord1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                sea1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                sin1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                sjc1 = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                syd1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', ),
                yyz1 = equinix.services.metalv1.models.spot_prices_per_new_facility.SpotPricesPerNewFacility(
                    baremetal_1e = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    href = '', )
            )
        else:
            return SpotPricesReport(
        )
        """

    def testSpotPricesReport(self):
        """Test SpotPricesReport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
