# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.payment_method_list import PaymentMethodList

class TestPaymentMethodList(unittest.TestCase):
    """PaymentMethodList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentMethodList:
        """Test PaymentMethodList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentMethodList`
        """
        model = PaymentMethodList()
        if include_optional:
            return PaymentMethodList(
                href = '',
                payment_methods = [
                    equinix.services.metalv1.models.payment_method.PaymentMethod(
                        billing_address = equinix.services.metalv1.models.payment_method_billing_address.PaymentMethodBillingAddress(
                            country_code_alpha2 = '', 
                            href = '', 
                            postal_code = '', 
                            street_address = '', ), 
                        card_type = '', 
                        cardholder_name = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by_user = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        default = True, 
                        email = '', 
                        expiration_month = '', 
                        expiration_year = '', 
                        href = '', 
                        id = '', 
                        name = '', 
                        organization = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        projects = [
                            
                            ], 
                        type = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaymentMethodList(
        )
        """

    def testPaymentMethodList(self):
        """Test PaymentMethodList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
