# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.ip_address import IPAddress

class TestIPAddress(unittest.TestCase):
    """IPAddress unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IPAddress:
        """Test IPAddress
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IPAddress`
        """
        model = IPAddress()
        if include_optional:
            return IPAddress(
                address_family = 4,
                cidr = 28,
                href = '',
                ip_reservations = [
                    ''
                    ],
                public = False
            )
        else:
            return IPAddress(
        )
        """

    def testIPAddress(self):
        """Test IPAddress"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
