# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_market_request_create_input import SpotMarketRequestCreateInput

class TestSpotMarketRequestCreateInput(unittest.TestCase):
    """SpotMarketRequestCreateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotMarketRequestCreateInput:
        """Test SpotMarketRequestCreateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotMarketRequestCreateInput`
        """
        model = SpotMarketRequestCreateInput()
        if include_optional:
            return SpotMarketRequestCreateInput(
                devices_max = 56,
                devices_min = 56,
                end_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                facilities = [
                    ''
                    ],
                href = '',
                instance_parameters = equinix.services.metalv1.models.spot_market_request_create_input_instance_parameters.SpotMarketRequestCreateInput_instance_parameters(
                    always_pxe = True, 
                    billing_cycle = '', 
                    customdata = equinix.services.metalv1.models.customdata.customdata(), 
                    description = '', 
                    features = [
                        ''
                        ], 
                    hostname = '', 
                    hostnames = [
                        ''
                        ], 
                    href = '', 
                    locked = True, 
                    no_ssh_keys = True, 
                    operating_system = '', 
                    plan = '', 
                    private_ipv4_subnet_size = 56, 
                    project_ssh_keys = [
                        ''
                        ], 
                    public_ipv4_subnet_size = 56, 
                    tags = [
                        ''
                        ], 
                    termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    user_ssh_keys = [
                        ''
                        ], 
                    userdata = '', ),
                max_bid_price = 1.337,
                metro = ''
            )
        else:
            return SpotMarketRequestCreateInput(
        )
        """

    def testSpotMarketRequestCreateInput(self):
        """Test SpotMarketRequestCreateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
