# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.batches_api import BatchesApi


class TestBatchesApi(unittest.TestCase):
    """BatchesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BatchesApi()

    def tearDown(self) -> None:
        pass

    def test_create_device_batch(self) -> None:
        """Test case for create_device_batch

        Create a devices batch
        """
        pass

    def test_delete_batch(self) -> None:
        """Test case for delete_batch

        Delete the Batch
        """
        pass

    def test_find_batch_by_id(self) -> None:
        """Test case for find_batch_by_id

        Retrieve a Batch
        """
        pass

    def test_find_batches_by_project(self) -> None:
        """Test case for find_batches_by_project

        Retrieve all batches by project
        """
        pass


if __name__ == '__main__':
    unittest.main()
