# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.ip_addresses_api import IPAddressesApi


class TestIPAddressesApi(unittest.TestCase):
    """IPAddressesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IPAddressesApi()

    def tearDown(self) -> None:
        pass

    def test_delete_ip_address(self) -> None:
        """Test case for delete_ip_address

        Unassign an ip address
        """
        pass

    def test_find_ip_address_by_id(self) -> None:
        """Test case for find_ip_address_by_id

        Retrieve an ip address
        """
        pass

    def test_find_ip_address_customdata(self) -> None:
        """Test case for find_ip_address_customdata

        Retrieve the custom metadata of an IP Reservation or IP Assignment
        """
        pass

    def test_find_ip_availabilities(self) -> None:
        """Test case for find_ip_availabilities

        Retrieve all available subnets of a particular reservation
        """
        pass

    def test_find_ip_reservations(self) -> None:
        """Test case for find_ip_reservations

        Retrieve all ip reservations
        """
        pass

    def test_request_ip_reservation(self) -> None:
        """Test case for request_ip_reservation

        Requesting IP reservations
        """
        pass

    def test_update_ip_address(self) -> None:
        """Test case for update_ip_address

        Update an ip address
        """
        pass


if __name__ == '__main__':
    unittest.main()
