# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.user_limited import UserLimited

class TestUserLimited(unittest.TestCase):
    """UserLimited unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserLimited:
        """Test UserLimited
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserLimited`
        """
        model = UserLimited()
        if include_optional:
            return UserLimited(
                avatar_thumb_url = '',
                avatar_url = '',
                full_name = '',
                href = '',
                id = ''
            )
        else:
            return UserLimited(
                id = '',
        )
        """

    def testUserLimited(self):
        """Test UserLimited"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
