# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.password_reset_tokens_api import PasswordResetTokensApi


class TestPasswordResetTokensApi(unittest.TestCase):
    """PasswordResetTokensApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasswordResetTokensApi()

    def tearDown(self) -> None:
        pass

    def test_create_password_reset_token(self) -> None:
        """Test case for create_password_reset_token

        Create a password reset token
        """
        pass

    def test_reset_password(self) -> None:
        """Test case for reset_password

        Reset current user password
        """
        pass


if __name__ == '__main__':
    unittest.main()
