# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.user_create_input import UserCreateInput

class TestUserCreateInput(unittest.TestCase):
    """UserCreateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserCreateInput:
        """Test UserCreateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserCreateInput`
        """
        model = UserCreateInput()
        if include_optional:
            return UserCreateInput(
                company_name = '',
                company_url = '',
                customdata = None,
                emails = [
                    equinix.services.metalv1.models.email_input.EmailInput(
                        address = '', 
                        default = True, 
                        href = '', )
                    ],
                first_name = '',
                href = '',
                invitation_id = '',
                last_name = '',
                level = '',
                nonce = '',
                password = '',
                phone_number = '',
                social_accounts = None,
                timezone = '',
                title = '',
                two_factor_auth = '',
                verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return UserCreateInput(
                emails = [
                    equinix.services.metalv1.models.email_input.EmailInput(
                        address = '', 
                        default = True, 
                        href = '', )
                    ],
                first_name = '',
                last_name = '',
        )
        """

    def testUserCreateInput(self):
        """Test UserCreateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
