# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.hardware_reservations_api import HardwareReservationsApi


class TestHardwareReservationsApi(unittest.TestCase):
    """HardwareReservationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = HardwareReservationsApi()

    def tearDown(self) -> None:
        pass

    def test_activate_hardware_reservation(self) -> None:
        """Test case for activate_hardware_reservation

        Activate a spare hardware reservation
        """
        pass

    def test_find_hardware_reservation_by_id(self) -> None:
        """Test case for find_hardware_reservation_by_id

        Retrieve a hardware reservation
        """
        pass

    def test_find_project_hardware_reservations(self) -> None:
        """Test case for find_project_hardware_reservations

        Retrieve all hardware reservations for a given project
        """
        pass

    def test_find_project_hardware_reservations_all_pages(self):
        """Test case for find_project_hardware_reservations_all_pages

        Retrieve all hardware reservations for a given project  # noqa: E501
        """
        pass

    def test_move_hardware_reservation(self) -> None:
        """Test case for move_hardware_reservation

        Move a hardware reservation
        """
        pass


if __name__ == '__main__':
    unittest.main()
