# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.capacity_api import CapacityApi


class TestCapacityApi(unittest.TestCase):
    """CapacityApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CapacityApi()

    def tearDown(self) -> None:
        pass

    def test_check_capacity_for_facility(self) -> None:
        """Test case for check_capacity_for_facility

        Check capacity
        """
        pass

    def test_check_capacity_for_metro(self) -> None:
        """Test case for check_capacity_for_metro

        Check capacity for a metro
        """
        pass

    def test_find_capacity_for_facility(self) -> None:
        """Test case for find_capacity_for_facility

        View capacity
        """
        pass

    def test_find_capacity_for_metro(self) -> None:
        """Test case for find_capacity_for_metro

        View capacity for metros
        """
        pass

    def test_find_organization_capacity_per_facility(self) -> None:
        """Test case for find_organization_capacity_per_facility

        View available hardware plans per Facility for given organization
        """
        pass

    def test_find_organization_capacity_per_metro(self) -> None:
        """Test case for find_organization_capacity_per_metro

        View available hardware plans per Metro for given organization
        """
        pass


if __name__ == '__main__':
    unittest.main()
