# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.interconnection_port import InterconnectionPort

class TestInterconnectionPort(unittest.TestCase):
    """InterconnectionPort unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InterconnectionPort:
        """Test InterconnectionPort
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InterconnectionPort`
        """
        model = InterconnectionPort()
        if include_optional:
            return InterconnectionPort(
                href = '',
                id = '',
                link_status = '',
                name = '',
                organization = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                role = 'primary',
                speed = 56,
                status = 'requested',
                switch_id = '',
                virtual_circuits = [
                    null
                    ]
            )
        else:
            return InterconnectionPort(
        )
        """

    def testInterconnectionPort(self):
        """Test InterconnectionPort"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
