# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.interconnection_metro_list_metros_inner import InterconnectionMetroListMetrosInner

class TestInterconnectionMetroListMetrosInner(unittest.TestCase):
    """InterconnectionMetroListMetrosInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InterconnectionMetroListMetrosInner:
        """Test InterconnectionMetroListMetrosInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InterconnectionMetroListMetrosInner`
        """
        model = InterconnectionMetroListMetrosInner()
        if include_optional:
            return InterconnectionMetroListMetrosInner(
                code = '',
                country = '',
                href = '',
                id = '',
                name = '',
                providers = [
                    equinix.services.metalv1.models.interconnection_metro_list_metros_inner_all_of_providers_inner.InterconnectionMetroList_metros_inner_allOf_providers_inner(
                        bandwidths = [
                            50
                            ], 
                        features = [
                            'high capacity'
                            ], 
                        href = '', 
                        locations = [
                            'us-east-1'
                            ], 
                        name = 'AWS Direct Connect', 
                        type = 'CSP_AWS', )
                    ]
            )
        else:
            return InterconnectionMetroListMetrosInner(
        )
        """

    def testInterconnectionMetroListMetrosInner(self):
        """Test InterconnectionMetroListMetrosInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
