# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.api.cloud_routers_api import CloudRoutersApi


class TestCloudRoutersApi(unittest.TestCase):
    """CloudRoutersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CloudRoutersApi()

    def tearDown(self) -> None:
        pass

    def test_create_cloud_router(self) -> None:
        """Test case for create_cloud_router

        Create Routers
        """
        pass

    def test_create_cloud_router_action(self) -> None:
        """Test case for create_cloud_router_action

        Create Route Table Action
        """
        pass

    def test_delete_cloud_router_by_uuid(self) -> None:
        """Test case for delete_cloud_router_by_uuid

        Delete Routers
        """
        pass

    def test_get_cloud_router_actions(self) -> None:
        """Test case for get_cloud_router_actions

        Get Route Table Actions
        """
        pass

    def test_get_cloud_router_actions_by_uuid(self) -> None:
        """Test case for get_cloud_router_actions_by_uuid

        Get Route Table Action by ID
        """
        pass

    def test_get_cloud_router_by_uuid(self) -> None:
        """Test case for get_cloud_router_by_uuid

        Get Routers
        """
        pass

    def test_get_cloud_router_package_by_code(self) -> None:
        """Test case for get_cloud_router_package_by_code

        Get Package Details
        """
        pass

    def test_get_cloud_router_packages(self) -> None:
        """Test case for get_cloud_router_packages

        List Packages
        """
        pass

    def test_search_cloud_router_routes(self) -> None:
        """Test case for search_cloud_router_routes

        Search Route Table
        """
        pass

    def test_search_cloud_routers(self) -> None:
        """Test case for search_cloud_routers

        Search Routers
        """
        pass

    def test_search_connection_advertised_routes(self) -> None:
        """Test case for search_connection_advertised_routes

        Search Advertised Routes
        """
        pass

    def test_search_connection_received_routes(self) -> None:
        """Test case for search_connection_received_routes

        Search Received Routes
        """
        pass

    def test_search_router_actions(self) -> None:
        """Test case for search_router_actions

        Search Route Table Actions
        """
        pass

    def test_update_cloud_router_by_uuid(self) -> None:
        """Test case for update_cloud_router_by_uuid

        Update Routers
        """
        pass


if __name__ == '__main__':
    unittest.main()
