# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.ssh_keys_api import SSHKeysApi


class TestSSHKeysApi(unittest.TestCase):
    """SSHKeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SSHKeysApi()

    def tearDown(self) -> None:
        pass

    def test_create_project_ssh_key(self) -> None:
        """Test case for create_project_ssh_key

        Create a ssh key for the given project
        """
        pass

    def test_create_ssh_key(self) -> None:
        """Test case for create_ssh_key

        Create a ssh key for the current user
        """
        pass

    def test_delete_ssh_key(self) -> None:
        """Test case for delete_ssh_key

        Delete the ssh key
        """
        pass

    def test_find_device_ssh_keys(self) -> None:
        """Test case for find_device_ssh_keys

        Retrieve a device's ssh keys
        """
        pass

    def test_find_project_ssh_keys(self) -> None:
        """Test case for find_project_ssh_keys

        Retrieve a project's ssh keys
        """
        pass

    def test_find_ssh_key_by_id(self) -> None:
        """Test case for find_ssh_key_by_id

        Retrieve a ssh key
        """
        pass

    def test_find_ssh_keys(self) -> None:
        """Test case for find_ssh_keys

        Retrieve all ssh keys
        """
        pass

    def test_update_ssh_key(self) -> None:
        """Test case for update_ssh_key

        Update the ssh key
        """
        pass


if __name__ == '__main__':
    unittest.main()
