# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_prices_per_facility import SpotPricesPerFacility

class TestSpotPricesPerFacility(unittest.TestCase):
    """SpotPricesPerFacility unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotPricesPerFacility:
        """Test SpotPricesPerFacility
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotPricesPerFacility`
        """
        model = SpotPricesPerFacility()
        if include_optional:
            return SpotPricesPerFacility(
                baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_2 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_2a = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_2a2 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_3 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_s = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                c2_medium_x86 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                href = '',
                m2_xlarge_x86 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, )
            )
        else:
            return SpotPricesPerFacility(
        )
        """

    def testSpotPricesPerFacility(self):
        """Test SpotPricesPerFacility"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
