# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.organizations_api import OrganizationsApi


class TestOrganizationsApi(unittest.TestCase):
    """OrganizationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_organization(self) -> None:
        """Test case for create_organization

        Create an organization
        """
        pass

    def test_create_organization_invitation(self) -> None:
        """Test case for create_organization_invitation

        Create an invitation for an organization
        """
        pass

    def test_create_organization_project(self) -> None:
        """Test case for create_organization_project

        Create a project for the organization
        """
        pass

    def test_create_payment_method(self) -> None:
        """Test case for create_payment_method

        Create a payment method for the given organization
        """
        pass

    def test_delete_organization(self) -> None:
        """Test case for delete_organization

        Delete the organization
        """
        pass

    def test_find_operating_systems_by_organization(self) -> None:
        """Test case for find_operating_systems_by_organization

        Retrieve all operating systems visible by the organization
        """
        pass

    def test_find_organization_by_id(self) -> None:
        """Test case for find_organization_by_id

        Retrieve an organization's details
        """
        pass

    def test_find_organization_customdata(self) -> None:
        """Test case for find_organization_customdata

        Retrieve the custom metadata of an organization
        """
        pass

    def test_find_organization_invitations(self) -> None:
        """Test case for find_organization_invitations

        Retrieve organization invitations
        """
        pass

    def test_find_organization_payment_methods(self) -> None:
        """Test case for find_organization_payment_methods

        Retrieve all payment methods of an organization
        """
        pass

    def test_find_organization_projects(self) -> None:
        """Test case for find_organization_projects

        Retrieve all projects of an organization
        """
        pass

    def test_find_organization_projects_all_pages(self):
        """Test case for find_organization_projects_all_pages

        Retrieve all projects of an organization  # noqa: E501
        """
        pass

    def test_find_organization_transfers(self) -> None:
        """Test case for find_organization_transfers

        Retrieve all project transfer requests from or to an organization
        """
        pass

    def test_find_organizations(self) -> None:
        """Test case for find_organizations

        Retrieve all organizations
        """
        pass

    def test_find_organizations_all_pages(self):
        """Test case for find_organizations_all_pages

        Retrieve all organizations  # noqa: E501
        """
        pass

    def test_find_plans_by_organization(self) -> None:
        """Test case for find_plans_by_organization

        Retrieve all plans visible by the organization
        """
        pass

    def test_update_organization(self) -> None:
        """Test case for update_organization

        Update the organization
        """
        pass


if __name__ == '__main__':
    unittest.main()
