# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.authentication_api import AuthenticationApi


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthenticationApi()

    def tearDown(self) -> None:
        pass

    def test_create_api_key(self) -> None:
        """Test case for create_api_key

        Create an API key
        """
        pass

    def test_create_project_api_key(self) -> None:
        """Test case for create_project_api_key

        Create an API key for a project.
        """
        pass

    def test_delete_api_key(self) -> None:
        """Test case for delete_api_key

        Delete the API key
        """
        pass

    def test_delete_user_api_key(self) -> None:
        """Test case for delete_user_api_key

        Delete the API key
        """
        pass

    def test_find_api_keys(self) -> None:
        """Test case for find_api_keys

        Retrieve all user API keys
        """
        pass

    def test_find_project_api_keys(self) -> None:
        """Test case for find_project_api_keys

        Retrieve all API keys for the project.
        """
        pass


if __name__ == '__main__':
    unittest.main()
