# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Optional
from equinix.services.fabricv4.models.cloud_router_actions_search_expression import CloudRouterActionsSearchExpression
from equinix.services.fabricv4.models.cloud_router_actions_search_or_filter import CloudRouterActionsSearchOrFilter
from typing import Union, Any, List, TYPE_CHECKING, Optional, Dict
from typing_extensions import Literal, Self
from pydantic import Field

CLOUDROUTERACTIONSSEARCHFILTER_ANY_OF_SCHEMAS = ["CloudRouterActionsSearchExpression", "CloudRouterActionsSearchOrFilter"]

class CloudRouterActionsSearchFilter(BaseModel):
    """
    CloudRouterActionsSearchFilter
    """

    # data type: CloudRouterActionsSearchExpression
    anyof_schema_1_validator: Optional[CloudRouterActionsSearchExpression] = None
    # data type: CloudRouterActionsSearchOrFilter
    anyof_schema_2_validator: Optional[CloudRouterActionsSearchOrFilter] = None
    if TYPE_CHECKING:
        actual_instance: Optional[Union[CloudRouterActionsSearchExpression, CloudRouterActionsSearchOrFilter]] = None
    else:
        actual_instance: Any = None
    any_of_schemas: List[str] = Field(default=Literal["CloudRouterActionsSearchExpression", "CloudRouterActionsSearchOrFilter"])

    model_config = {
        "validate_assignment": True,
        "protected_namespaces": (),
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_anyof(cls, v):
        instance = CloudRouterActionsSearchFilter.model_construct()
        error_messages = []
        # validate data type: CloudRouterActionsSearchExpression
        if not isinstance(v, CloudRouterActionsSearchExpression):
            error_messages.append(f"Error! Input type `{type(v)}` is not `CloudRouterActionsSearchExpression`")
        else:
            return v

        # validate data type: CloudRouterActionsSearchOrFilter
        if not isinstance(v, CloudRouterActionsSearchOrFilter):
            error_messages.append(f"Error! Input type `{type(v)}` is not `CloudRouterActionsSearchOrFilter`")
        else:
            return v

        if error_messages:
            # no match
            raise ValueError("No match found when setting the actual_instance in CloudRouterActionsSearchFilter with anyOf schemas: CloudRouterActionsSearchExpression, CloudRouterActionsSearchOrFilter. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        # anyof_schema_1_validator: Optional[CloudRouterActionsSearchExpression] = None
        try:
            instance.actual_instance = CloudRouterActionsSearchExpression.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_2_validator: Optional[CloudRouterActionsSearchOrFilter] = None
        try:
            instance.actual_instance = CloudRouterActionsSearchOrFilter.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))

        if error_messages:
            # no match
            raise ValueError("No match found when deserializing the JSON string into CloudRouterActionsSearchFilter with anyOf schemas: CloudRouterActionsSearchExpression, CloudRouterActionsSearchOrFilter. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], CloudRouterActionsSearchExpression, CloudRouterActionsSearchOrFilter]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())


