# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.auth_token_list import AuthTokenList

class TestAuthTokenList(unittest.TestCase):
    """AuthTokenList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthTokenList:
        """Test AuthTokenList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthTokenList`
        """
        model = AuthTokenList()
        if include_optional:
            return AuthTokenList(
                api_keys = [
                    equinix.services.metalv1.models.auth_token.AuthToken(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        href = '', 
                        id = '', 
                        project = null, 
                        read_only = True, 
                        token = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        user = null, )
                    ],
                href = ''
            )
        else:
            return AuthTokenList(
        )
        """

    def testAuthTokenList(self):
        """Test AuthTokenList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
