# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.line_item import LineItem

class TestLineItem(unittest.TestCase):
    """LineItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LineItem:
        """Test LineItem
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LineItem`
        """
        model = LineItem()
        if include_optional:
            return LineItem(
                adjustments = [
                    equinix.services.metalv1.models.line_item_adjustment.LineItemAdjustment(
                        amount = 1.337, 
                        description = '', 
                        href = '', )
                    ],
                amount = 1.337,
                currency = '',
                description = '',
                details = '',
                end_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                hostname = '',
                href = '',
                item_type = '',
                location = '',
                plan = equinix.services.metalv1.models.plan_id_name.PlanIdName(
                    href = '', 
                    id = '', 
                    name = '', ),
                plan_id = '',
                project = equinix.services.metalv1.models.project_id_name.ProjectIdName(
                    href = '', 
                    id = '', 
                    name = '', ),
                project_id = '',
                service_id = '',
                start_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                unit = '',
                unit_price = 1.337
            )
        else:
            return LineItem(
        )
        """

    def testLineItem(self):
        """Test LineItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
