# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.entitlement import Entitlement

class TestEntitlement(unittest.TestCase):
    """Entitlement unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Entitlement:
        """Test Entitlement
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Entitlement`
        """
        model = Entitlement()
        if include_optional:
            return Entitlement(
                description = '',
                feature_access = None,
                href = '',
                id = '',
                instance_quota = None,
                ip_quota = None,
                name = '',
                project_quota = 56,
                slug = '',
                volume_limits = None,
                volume_quota = None,
                weight = 56
            )
        else:
            return Entitlement(
                id = '',
                slug = '',
                weight = 56,
        )
        """

    def testEntitlement(self):
        """Test Entitlement"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
