# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.bgp_api import BGPApi


class TestBGPApi(unittest.TestCase):
    """BGPApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BGPApi()

    def tearDown(self) -> None:
        pass

    def test_delete_bgp_session(self) -> None:
        """Test case for delete_bgp_session

        Delete the BGP session
        """
        pass

    def test_find_bgp_config_by_project(self) -> None:
        """Test case for find_bgp_config_by_project

        Retrieve a bgp config
        """
        pass

    def test_find_bgp_session_by_id(self) -> None:
        """Test case for find_bgp_session_by_id

        Retrieve a BGP session
        """
        pass

    def test_find_global_bgp_ranges(self) -> None:
        """Test case for find_global_bgp_ranges

        Retrieve all global bgp ranges
        """
        pass

    def test_find_project_bgp_sessions(self) -> None:
        """Test case for find_project_bgp_sessions

        Retrieve all BGP sessions for project
        """
        pass

    def test_request_bgp_config(self) -> None:
        """Test case for request_bgp_config

        Requesting bgp config
        """
        pass

    def test_update_bgp_session(self) -> None:
        """Test case for update_bgp_session

        Update the BGP session
        """
        pass


if __name__ == '__main__':
    unittest.main()
