# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.metal_gateway_lite import MetalGatewayLite

class TestMetalGatewayLite(unittest.TestCase):
    """MetalGatewayLite unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MetalGatewayLite:
        """Test MetalGatewayLite
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MetalGatewayLite`
        """
        model = MetalGatewayLite()
        if include_optional:
            return MetalGatewayLite(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                gateway_address = '10.1.2.1/27',
                href = '',
                id = '',
                state = 'ready',
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                vlan = 1001
            )
        else:
            return MetalGatewayLite(
        )
        """

    def testMetalGatewayLite(self):
        """Test MetalGatewayLite"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
