# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.vlan_fabric_vc_create_input import VlanFabricVcCreateInput

class TestVlanFabricVcCreateInput(unittest.TestCase):
    """VlanFabricVcCreateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VlanFabricVcCreateInput:
        """Test VlanFabricVcCreateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VlanFabricVcCreateInput`
        """
        model = VlanFabricVcCreateInput()
        if include_optional:
            return VlanFabricVcCreateInput(
                contact_email = '',
                description = '',
                facility_id = '',
                href = '',
                metro = '',
                name = '',
                project = '',
                redundancy = '',
                service_token_type = 'a_side',
                speed = '10000000000',
                tags = [
                    ''
                    ],
                type = 'shared',
                vlans = [1000,1001]
            )
        else:
            return VlanFabricVcCreateInput(
                metro = '',
                name = '',
                redundancy = '',
                service_token_type = 'a_side',
                type = 'shared',
                vlans = [1000,1001],
        )
        """

    def testVlanFabricVcCreateInput(self):
        """Test VlanFabricVcCreateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
