# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_market_prices_per_metro_report import SpotMarketPricesPerMetroReport

class TestSpotMarketPricesPerMetroReport(unittest.TestCase):
    """SpotMarketPricesPerMetroReport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotMarketPricesPerMetroReport:
        """Test SpotMarketPricesPerMetroReport
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotMarketPricesPerMetroReport`
        """
        model = SpotMarketPricesPerMetroReport()
        if include_optional:
            return SpotMarketPricesPerMetroReport(
                am = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                ch = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                da = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                href = '',
                la = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                ny = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                sg = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                sv = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , )
            )
        else:
            return SpotMarketPricesPerMetroReport(
        )
        """

    def testSpotMarketPricesPerMetroReport(self):
        """Test SpotMarketPricesPerMetroReport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
