# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.vrf_virtual_circuit_update_input import VrfVirtualCircuitUpdateInput

class TestVrfVirtualCircuitUpdateInput(unittest.TestCase):
    """VrfVirtualCircuitUpdateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VrfVirtualCircuitUpdateInput:
        """Test VrfVirtualCircuitUpdateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VrfVirtualCircuitUpdateInput`
        """
        model = VrfVirtualCircuitUpdateInput()
        if include_optional:
            return VrfVirtualCircuitUpdateInput(
                customer_ip = '12.0.0.2',
                customer_ipv6 = '2604:1380:4641:a00::6',
                description = '',
                href = '',
                md5 = 'jUR,rZ#UM/?R,Fp^l6$ARjeJk C>i H'qT\\{<?'es#)#iK.YM{Rag2/!KB!k@5oXh.:Ts\";mGL,i&z5[P@M\"lzfB+Y,Twzfu~N^z\"mfqecVU{SE{QA<Y8XX0<}J;Krm9W'g~?)DvDDL7BlwpCDcpNjORpuEG',
                metal_ip = '12.0.0.1',
                metal_ipv6 = '2604:1380:4641:a00::6',
                name = '',
                peer_asn = 65000,
                speed = '',
                subnet = '12.0.0.0/30',
                subnet_ipv6 = '2604:1380:4641:a00::4/126',
                tags = [
                    ''
                    ]
            )
        else:
            return VrfVirtualCircuitUpdateInput(
        )
        """

    def testVrfVirtualCircuitUpdateInput(self):
        """Test VrfVirtualCircuitUpdateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
