# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.invitations_api import InvitationsApi


class TestInvitationsApi(unittest.TestCase):
    """InvitationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InvitationsApi()

    def tearDown(self) -> None:
        pass

    def test_accept_invitation(self) -> None:
        """Test case for accept_invitation

        Accept an invitation
        """
        pass

    def test_decline_invitation(self) -> None:
        """Test case for decline_invitation

        Decline an invitation
        """
        pass

    def test_find_invitation_by_id(self) -> None:
        """Test case for find_invitation_by_id

        View an invitation
        """
        pass


if __name__ == '__main__':
    unittest.main()
