# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.licenses_api import LicensesApi


class TestLicensesApi(unittest.TestCase):
    """LicensesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LicensesApi()

    def tearDown(self) -> None:
        pass

    def test_create_license(self) -> None:
        """Test case for create_license

        Create a License
        """
        pass

    def test_delete_license(self) -> None:
        """Test case for delete_license

        Delete the license
        """
        pass

    def test_find_license_by_id(self) -> None:
        """Test case for find_license_by_id

        Retrieve a license
        """
        pass

    def test_find_project_licenses(self) -> None:
        """Test case for find_project_licenses

        Retrieve all licenses
        """
        pass

    def test_update_license(self) -> None:
        """Test case for update_license

        Update the license
        """
        pass


if __name__ == '__main__':
    unittest.main()
