# flake8: noqa

# import apis into api package
from equinix.services.fabricv4.api.cloud_routers_api import CloudRoutersApi
from equinix.services.fabricv4.api.connections_api import ConnectionsApi
from equinix.services.fabricv4.api.health_api import HealthApi
from equinix.services.fabricv4.api.marketplace_subscriptions_api import MarketplaceSubscriptionsApi
from equinix.services.fabricv4.api.metros_api import MetrosApi
from equinix.services.fabricv4.api.networks_api import NetworksApi
from equinix.services.fabricv4.api.ports_api import PortsApi
from equinix.services.fabricv4.api.precision_time_api import PrecisionTimeApi
from equinix.services.fabricv4.api.prices_api import PricesApi
from equinix.services.fabricv4.api.route_aggregation_rules_api import RouteAggregationRulesApi
from equinix.services.fabricv4.api.route_aggregations_api import RouteAggregationsApi
from equinix.services.fabricv4.api.route_filter_rules_api import RouteFilterRulesApi
from equinix.services.fabricv4.api.route_filters_api import RouteFiltersApi
from equinix.services.fabricv4.api.routing_protocols_api import RoutingProtocolsApi
from equinix.services.fabricv4.api.service_profiles_api import ServiceProfilesApi
from equinix.services.fabricv4.api.service_tokens_api import ServiceTokensApi
from equinix.services.fabricv4.api.statistics_api import StatisticsApi
from equinix.services.fabricv4.api.stream_subscriptions_api import StreamSubscriptionsApi
from equinix.services.fabricv4.api.streams_api import StreamsApi

