# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.batches_list import BatchesList

class TestBatchesList(unittest.TestCase):
    """BatchesList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BatchesList:
        """Test BatchesList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BatchesList`
        """
        model = BatchesList()
        if include_optional:
            return BatchesList(
                batches = [
                    equinix.services.metalv1.models.batch.Batch(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        devices = [
                            equinix.services.metalv1.models.href.Href(
                                href = '', )
                            ], 
                        error_messages = [
                            ''
                            ], 
                        href = '', 
                        id = '', 
                        project = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        quantity = 56, 
                        state = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                href = ''
            )
        else:
            return BatchesList(
        )
        """

    def testBatchesList(self):
        """Test BatchesList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
