# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.metal_gateway_elastic_ip_create_input import MetalGatewayElasticIpCreateInput

class TestMetalGatewayElasticIpCreateInput(unittest.TestCase):
    """MetalGatewayElasticIpCreateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MetalGatewayElasticIpCreateInput:
        """Test MetalGatewayElasticIpCreateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MetalGatewayElasticIpCreateInput`
        """
        model = MetalGatewayElasticIpCreateInput()
        if include_optional:
            return MetalGatewayElasticIpCreateInput(
                address = '147.75.234.8/31',
                customdata = { },
                href = '',
                next_hop = '192.168.12.13',
                tags = ["NY","prod","public"]
            )
        else:
            return MetalGatewayElasticIpCreateInput(
                address = '147.75.234.8/31',
                next_hop = '192.168.12.13',
        )
        """

    def testMetalGatewayElasticIpCreateInput(self):
        """Test MetalGatewayElasticIpCreateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
