# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_create_user(self) -> None:
        """Test case for create_user

        Create a user
        """
        pass

    def test_find_current_user(self) -> None:
        """Test case for find_current_user

        Retrieve the current user
        """
        pass

    def test_find_invitations(self) -> None:
        """Test case for find_invitations

        Retrieve current user invitations
        """
        pass

    def test_find_user_by_id(self) -> None:
        """Test case for find_user_by_id

        Retrieve a user
        """
        pass

    def test_find_user_customdata(self) -> None:
        """Test case for find_user_customdata

        Retrieve the custom metadata of a user
        """
        pass

    def test_find_users(self) -> None:
        """Test case for find_users

        Retrieve all users
        """
        pass

    def test_find_users_all_pages(self):
        """Test case for find_users_all_pages

        Retrieve all users  # noqa: E501
        """
        pass

    def test_update_current_user(self) -> None:
        """Test case for update_current_user

        Update the current user
        """
        pass


if __name__ == '__main__':
    unittest.main()
