# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.metal_gateways_api import MetalGatewaysApi


class TestMetalGatewaysApi(unittest.TestCase):
    """MetalGatewaysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MetalGatewaysApi()

    def tearDown(self) -> None:
        pass

    def test_create_bgp_dynamic_neighbor(self) -> None:
        """Test case for create_bgp_dynamic_neighbor

        Create a VRF BGP Dynamic Neighbor range
        """
        pass

    def test_create_metal_gateway(self) -> None:
        """Test case for create_metal_gateway

        Create a metal gateway
        """
        pass

    def test_create_metal_gateway_elastic_ip(self) -> None:
        """Test case for create_metal_gateway_elastic_ip

        Create a Metal Gateway Elastic IP
        """
        pass

    def test_delete_metal_gateway(self) -> None:
        """Test case for delete_metal_gateway

        Deletes the metal gateway
        """
        pass

    def test_find_metal_gateway_by_id(self) -> None:
        """Test case for find_metal_gateway_by_id

        Returns the metal gateway
        """
        pass

    def test_find_metal_gateways_by_project(self) -> None:
        """Test case for find_metal_gateways_by_project

        Returns all metal gateways for a project
        """
        pass

    def test_find_metal_gateways_by_project_all_pages(self):
        """Test case for find_metal_gateways_by_project_all_pages

        Returns all metal gateways for a project  # noqa: E501
        """
        pass

    def test_get_bgp_dynamic_neighbors(self) -> None:
        """Test case for get_bgp_dynamic_neighbors

        List BGP Dynamic Neighbors
        """
        pass

    def test_get_metal_gateway_elastic_ips(self) -> None:
        """Test case for get_metal_gateway_elastic_ips

        List Metal Gateway Elastic IPs
        """
        pass


if __name__ == '__main__':
    unittest.main()
